# -*- coding: utf-8 -*-

from django.conf.urls import url
from django_file_upload import views as file_views

from api import admin_views, mini_views, oauth_views, pack_views
from pay import views as pay_views
from live import views as live_views


urlpatterns = [
    url(r'^mini/login$', mini_views.mini_login_api, name='mini_login_api'),  # 小程序登录
    url(r'^mini/userinfo$', mini_views.get_userinfo_api, name='get_userinfo_api'),  # 获取用户信息
]

urlpatterns += [
    url(r'^pack$', pack_views.pack_detail, name='pack_detail'),
]

urlpatterns += [
    url(r'^pay/wx/order_create$', pay_views.wx_order_create_api, name='wx_order_create_api'),   # 订单创建
    url(r'^pay/wx/order/cancel$', pay_views.order_cancel, name='order_cancel'),   # 订单创建
    url(r'^pay/wx/notify_url$', pay_views.wx_notify_url_api, name='wx_notify_url_api'),  # 支付异步通知回调地址
]

#直播相关
urlpatterns += [
    url(r'^live/anchor/detail$', live_views.anchor_detail, name='anchor_detail'),   # 微信直播间列表
    url(r'^live/goods/detail$', live_views.room_goods_detail, name='room_goods_detail'),
    url(r'^live/order/create$', live_views.live_order_create, name='live_order_create'),
    url(r'^live/order/cancel$', live_views.live_order_cancel, name='live_order_cancel'),
    url(r'^live/pay/notify_url$', live_views.notify_url_api, name='notify_url_api'),
    url(r'^live/room/anchor/detail$', live_views.room_anchor_details, name='room_anchor_details'),
    url(r'^mini/live/login$', mini_views.mini_live_login_api, name='mini_live_login_api'),
]

# 图片上传
urlpatterns += [
    url(r'^upload$', file_views.file_upload, name='file_upload'),
]

urlpatterns += [
    url(r'^admin/login$', admin_views.login, name='login'),

    url(r'^admin/order/list$', admin_views.order_list, name='order_list'),   # 订单列表
    url(r'^admin/order/update$', admin_views.order_update, name='order_update'),   # 订单列表

    # 直播
    url(r'^admin/live/goods/list$', admin_views.live_goods_list, name='live_goods_list'),   # 直播商品库列表
    url(r'^admin/live/goods/create$', admin_views.live_goods_create, name='live_goods_create'),
    url(r'^admin/live/goods/delete$', admin_views.live_goods_delete, name='live_goods_delete'),
    url(r'^admin/live/goods/audit$', admin_views.live_goods_audit, name='live_goods_audit'),

    url(r'^admin/live/room/list$', admin_views.live_room_list, name='live_room_list'),   # 直播间列表

    url(r'^admin/live/order/list$', admin_views.live_order_list, name='live_order_list'),   # 直播间订单列表
    url(r'^admin/live/order/delivery$', admin_views.live_order_delivery, name='live_order_delivery'), # 直播间订单发货

    url(r'^admin/room/goods/list$', admin_views.room_goods_list, name='room_goods_list'), # 直播间商品

    #微信直播 api
    url(r'^admin/live/wx/room/list$', admin_views.fetch_wx_room_list, name='fetch_wx_room_list'),   # 微信直播间列表
]

urlpatterns += [
    url(r'^3rd/or$', oauth_views.oauth_redirect, name='3rd_or'),
    url(r'^3rd/oauth_redirect$', oauth_views.oauth_redirect, name='3rd_oauth_redirect'),
]
